@@ -1,8 +1,9 @@
+if(require(RWordXML)) {
 if(!file.exists("foo.R"))
    cat("f =\nfunction() {\n 1\n}\n", file = "foo.R")
 
 library(ROOXML)
-library(RWordXML)
+
 
 #ar = wordDoc("foo.docx")
 ar = createOODoc("foo.docx")
@@ -14,3 +15,4 @@ ar[["x/bob"]]
 ar = wordDoc("bar.docx")
 ar[c("x/bob", "jane")] = list("foo.R", I("inlined\ncontent"))
 names(ar)
+}
